==> qmmp-0.7.5.tar.bz2: qmmp-0.7.5/src/plugins/Visual/analyzer/translations/analyzer_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>Analyzer</name>
    <message>
        <location filename="../analyzer.cpp" line="56"/>
        <source>Qmmp Analyzer</source>
        <translation>Analizador Qmmp</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="77"/>
        <source>F</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ColorWidget</name>
    <message>
        <location filename="../colorwidget.cpp" line="37"/>
        <source>Select Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Analyzer Plugin Settings</source>
        <translation>Configuración del módulo analizador</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="26"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Show peaks</source>
        <translation>Mostrar picos</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Analyzer falloff:</source>
        <translation>Caída del analizador:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="56"/>
        <location filename="../settingsdialog.ui" line="98"/>
        <source>Slowest</source>
        <translation>Muy lenta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Slow</source>
        <translation>Lenta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="66"/>
        <location filename="../settingsdialog.ui" line="108"/>
        <source>Medium</source>
        <translation>Media</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <location filename="../settingsdialog.ui" line="113"/>
        <source>Fast</source>
        <translation>Rápida</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <location filename="../settingsdialog.ui" line="118"/>
        <source>Fastest</source>
        <translation>Muy rápida</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="84"/>
        <source>Peaks falloff:</source>
        <translation>Caída de picos:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="126"/>
        <source>Refresh rate:</source>
        <translation>Velocidad de actualización:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="140"/>
        <source>50 FPS</source>
        <translation>50 FPS</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="145"/>
        <source>25 FPS</source>
        <translation>25 FPS</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="150"/>
        <source>10 FPS</source>
        <translation>10 FPS</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="155"/>
        <source>5 FPS</source>
        <translation>5 FPS</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="163"/>
        <source>Cells size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="223"/>
        <source>Colors</source>
        <translation>Colores</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="229"/>
        <source>Peaks:</source>
        <translation>Picos:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="261"/>
        <source>Analyzer #1:</source>
        <translation>Analizador nº1:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="293"/>
        <source>Background:</source>
        <translation>Fondo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="325"/>
        <source>Analyzer #2:</source>
        <translation>Analizador nº2:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="370"/>
        <source>Analyzer #3:</source>
        <translation>Analizzatore NÂ° 3:</translation>
    </message>
</context>
<context>
    <name>VisualAnalyzerFactory</name>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="30"/>
        <source>Analyzer Plugin</source>
        <translation>Modulo analizzatore</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="49"/>
        <source>About Analyzer Visual Plugin</source>
        <translation>Info sul modulo Analizzatore visivo</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="50"/>
        <source>Qmmp Analyzer Visual Plugin</source>
        <translation>Modulo Analizzatore visivo Qmmp</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autore: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>

==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/Visual/analyzer/translations/analyzer_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>Analyzer</name>
    <message>
        <location filename="../analyzer.cpp" line="47"/>
        <source>Qmmp Analyzer</source>
        <translation>Analizador Qmmp</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="364"/>
        <source>Peaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="367"/>
        <source>Refresh Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="370"/>
        <source>50 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="371"/>
        <source>25 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="372"/>
        <source>10 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="373"/>
        <source>5 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="380"/>
        <source>Analyzer Falloff</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="383"/>
        <location filename="../analyzer.cpp" line="397"/>
        <source>Slowest</source>
        <translation type="unfinished">Muy lenta</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="384"/>
        <location filename="../analyzer.cpp" line="398"/>
        <source>Slow</source>
        <translation type="unfinished">Lenta</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="385"/>
        <location filename="../analyzer.cpp" line="399"/>
        <source>Medium</source>
        <translation type="unfinished">Media</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="386"/>
        <location filename="../analyzer.cpp" line="400"/>
        <source>Fast</source>
        <translation type="unfinished">Rápida</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="387"/>
        <location filename="../analyzer.cpp" line="401"/>
        <source>Fastest</source>
        <translation type="unfinished">Muy rápida</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="394"/>
        <source>Peaks Falloff</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="408"/>
        <source>F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="408"/>
        <source>&amp;Full Screen</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ColorWidget</name>
    <message>
        <location filename="../colorwidget.cpp" line="37"/>
        <source>Select Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Analyzer Plugin Settings</source>
        <translation>Configuración del módulo analizador</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Cells size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="101"/>
        <source>Colors</source>
        <translation>Colores</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Peaks:</source>
        <translation>Picos:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>Analyzer #1:</source>
        <translation>Analizador nº1:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="171"/>
        <source>Background:</source>
        <translation>Fondo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="203"/>
        <source>Analyzer #2:</source>
        <translation>Analizador nº2:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="248"/>
        <source>Analyzer #3:</source>
        <translation>Analizzatore NÂ° 3:</translation>
    </message>
</context>
<context>
    <name>VisualAnalyzerFactory</name>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="30"/>
        <source>Analyzer Plugin</source>
        <translation>Modulo analizzatore</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="49"/>
        <source>About Analyzer Visual Plugin</source>
        <translation>Info sul modulo Analizzatore visivo</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="50"/>
        <source>Qmmp Analyzer Visual Plugin</source>
        <translation>Modulo Analizzatore visivo Qmmp</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autore: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
